@@ -1,6 +1,6 @@
 package TPath::Attributes::Extended;
 {
-  $TPath::Attributes::Extended::VERSION = '0.005';
+  $TPath::Attributes::Extended::VERSION = '0.006';
 }
 
 # ABSTRACT: a collection of attributes beyond the standard set
@@ -11,116 +11,116 @@ use MooseX::MethodAttributes::Role;
 use List::Util qw(max min sum reduce);
 
 
-sub extended_abs : Attr(m%3Aabs) {
+sub extended_abs : Attr(m:abs) {
     abs $_[4];
 }
 
 
 
-sub extended_ceil : Attr(m%3Aceil) {
+sub extended_ceil : Attr(m:ceil) {
     require POSIX;
     POSIX::ceil( $_[4] );
 }
 
 
-sub extended_floor : Attr(m%3Afloor) {
+sub extended_floor : Attr(m:floor) {
     require POSIX;
     POSIX::floor( $_[4] );
 }
 
 
-sub extended_int : Attr(m%3Aint) {
+sub extended_int : Attr(m:int) {
     int $_[4];
 }
 
 
-sub extended_round : Attr(m%3Around) {
+sub extended_round : Attr(m:round) {
     sprintf '%.0f', $_[4];
 }
 
 
-sub extended_max : Attr(m%3Amax) {
+sub extended_max : Attr(m:max) {
     max @_[ 4 .. $#_ ];
 }
 
 
-sub extended_min : Attr(m%3Amin) {
+sub extended_min : Attr(m:min) {
     min @_[ 4 .. $#_ ];
 }
 
 
-sub extended_sum : Attr(m%3Asum) {
+sub extended_sum : Attr(m:sum) {
     sum @_[ 4 .. $#_ ];
 }
 
 
-sub extended_prod : Attr(m%3Aprod) {
+sub extended_prod : Attr(m:prod) {
     0 + reduce { $a * $b } @_[ 4 .. $#_ ];
 }
 
 
-sub extended_matches : Attr(s%3Amatches) {
+sub extended_matches : Attr(s:matches) {
     my ( $str, $re ) = @_[ 4, 5 ];
     ( $str // '' ) =~ /^$re$/ ? 1 : undef;
 }
 
 
-sub extended_looking_at : Attr(s%3Alooking-at) {
+sub extended_looking_at : Attr(s:looking-at) {
     my ( $str, $re ) = @_[ 4, 5 ];
     $str =~ /^$re/ ? 1 : undef;
 }
 
 
-sub extended_find : Attr(s%3Afind) {
+sub extended_find : Attr(s:find) {
     my ( $str, $re ) = @_[ 4, 5 ];
     $str =~ /$re/ ? 1 : undef;
 }
 
 
-sub extended_starts_with : Attr(s%3Astarts-with) {
+sub extended_starts_with : Attr(s:starts-with) {
     my ( $str, $prefix ) = @_[ 4, 5 ];
     0 == index $str, $prefix ? 1 : undef;
 }
 
 
-sub extended_ends_with : Attr(s%3Aends-with) {
+sub extended_ends_with : Attr(s:ends-with) {
     my ( $str, $suffix ) = @_[ 4, 5 ];
     -1 < index( $str, $suffix, length($str) - length($suffix) ) ? 1 : undef;
 }
 
 
-sub extended_contains : Attr(s%3Acontains) {
+sub extended_contains : Attr(s:contains) {
     my ( $str, $infix ) = @_[ 4, 5 ];
     -1 < index( $str, $infix ) ? 1 : undef;
 }
 
 
-sub extended_index : Attr(s%3Aindex) {
+sub extended_index : Attr(s:index) {
     my ( $str, $infix ) = @_[ 4, 5 ];
     index $str, $infix;
 }
 
 
-sub extended_concat : Attr(s%3Aconcat) {
+sub extended_concat : Attr(s:concat) {
     join '', @_[ 4 .. $#_ ];
 }
 
 
-sub extended_replace_first : Attr(s%3Areplace-first) {
+sub extended_replace_first : Attr(s:replace-first) {
     my ( $str, $rx, $rep ) = @_[ 4 .. 6 ];
     $str =~ s/$rx/$rep/;
     $str;
 }
 
 
-sub extended_replace_all : Attr(s%3Areplace-all) {
+sub extended_replace_all : Attr(s:replace-all) {
     my ( $str, $rx, $rep ) = @_[ 4 .. 6 ];
     $str =~ s/$rx/$rep/g;
     $str;
 }
 
 
-sub extended_replace : Attr(s%3Areplace) {
+sub extended_replace : Attr(s:replace) {
     my ( $str, $ss, $rep ) = @_[ 4 .. 6 ];
     my $l     = length $ss;
     my $start = 0;
@@ -136,13 +136,13 @@ sub extended_replace : Attr(s%3Areplace) {
 }
 
 
-sub extended_compare : Attr(s%3Acmp) {
+sub extended_compare : Attr(s:cmp) {
     my ( $s1, $s2 ) = @_[ 4, 5 ];
     $s1 cmp $s2;
 }
 
 
-sub extended_substr : Attr(s%3Asubstr) {
+sub extended_substr : Attr(s:substr) {
     my ( $s, $i1, $i2 ) = @_[ 4 .. 6 ];
     if ( defined $i2 ) {
         substr $s, $i1, $i2 - $i1;
@@ -153,47 +153,47 @@ sub extended_substr : Attr(s%3Asubstr) {
 }
 
 
-sub extended_len : Attr(s%3Alen) {
+sub extended_len : Attr(s:len) {
     length $_[4];
 }
 
 
-sub extended_uc : Attr(s%3Auc) {
+sub extended_uc : Attr(s:uc) {
     uc $_[4];
 }
 
 
-sub extended_lc : Attr(s%3Alc) {
+sub extended_lc : Attr(s:lc) {
     lc $_[4];
 }
 
 
-sub extended_uc_first : Attr(s%3Aucfirst) {
+sub extended_uc_first : Attr(s:ucfirst) {
     ucfirst $_[4];
 }
 
 
-sub extended_trim : Attr(s%3Atrim) {
+sub extended_trim : Attr(s:trim) {
     ( my $s = $_[4] ) =~ s/^\s++|\s++$//g;
     $s;
 }
 
 
-sub extended_nspace : Attr(s%3Anspace) {
+sub extended_nspace : Attr(s:nspace) {
     my $s = extended_trim(@_);
     $s =~ s/\s++/ /g;
     $s;
 }
 
 
-sub extended_join : Attr(s%3Ajoin) {
+sub extended_join : Attr(s:join) {
     my ( $sep, @strings ) = @_[ 4 .. $#_ ];
     $sep //= 'null';
     join "$sep", @strings;
 }
 
 
-sub extended_millis : Attr(u%3Amillis) {
+sub extended_millis : Attr(u:millis) {
     require Time::HiRes;
     my ( $s, $m ) = Time::HiRes::gettimeofday();
     $m = int( $m / 1000 );
@@ -201,7 +201,7 @@ sub extended_millis : Attr(u%3Amillis) {
 }
 
 
-sub extended_udef : Attr(u%3Adef) {
+sub extended_udef : Attr(u:def) {
     defined $_[4] ? 1 : undef;
 }
 
@@ -217,7 +217,7 @@ TPath::Attributes::Extended - a collection of attributes beyond the standard set
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 SYNOPSIS
 
